@@ -405,7 +405,7 @@ Script::Name *ScriptCompiler::include(const char *token)
 	if(!prefix)
 		return NULL;
 
-	snprintf(buffer, sizeof(buffer), "%s/%s.mod", prefix, token);
+	snprintf(buffer, sizeof(buffer), "%s/%s.mac", prefix, token);
 
 	inc = getScript(token);
 	if(!inc)
@@ -481,7 +481,7 @@ int ScriptCompiler::compile(istream *str, char *name, const char *scrname)
 
 	scrStream = str;
 
-	if(cp && !stricmp(cp, ".mod"))
+	if(cp && !stricmp(cp, ".mac"))
 		bm = true;
 
 	if(bm)
@@ -490,7 +490,7 @@ int ScriptCompiler::compile(istream *str, char *name, const char *scrname)
 	gvarname[0] = '%';
 	
 	if(bm)
-		snprintf(gvarname + 1, 56, "mod.%s.", name);
+		snprintf(gvarname + 1, 56, "mac.%s.", name);
 	else
 		snprintf(gvarname + 1, 56, "scr.%s.", name);
 
@@ -767,7 +767,7 @@ repname1:
 
 			if(!mask)
 			{
-				slog.error("%s: unknown trap id; %s(%d)", token + 1, filename, lnum);
+				slog.error("%s(%d): %s: unknown trap id", filename, lnum, token + 1);
 				continue;
 			}
 
@@ -800,11 +800,11 @@ repname1:
 			if(NULL != (token = getToken()))
 			{
 				if(!Script::use(token))
-					slog.warn() << token << ": package missing" << endl;
+					slog.warn("%s(%d): %s: package missing", filename, lnum, token);
 			}
 			else
 			{
-				slog.error() << "use: name missing" << endl;
+				slog.error("%s(%d): use: name missing", filename, lnum);
 				continue;
 			}
 			snprintf(catchname, sizeof(catchname), "use.%s", token);
@@ -869,7 +869,7 @@ repname1:
 
 			addmask = submask = 0;
 			if(!ignore)
-				slog.error("%s: %s; %s(%d)", token, errmsg, filename, lnum);
+				slog.error("%s(%d): %s: %s", filename, lnum, token, errmsg);
 			continue;
 		}
 
@@ -1005,7 +1005,7 @@ repname1:
 				line->loop = loopid * 128 + looplevel;
 				if(!looplevel)
 				{
-					slog.error("loop: nesting error %s(%d)", filename, lnum);
+					slog.error("%s(%d): loop nesting error", filename, line->lnum);
 					continue;
 				}
 				else
@@ -1019,7 +1019,7 @@ repname1:
 		if(err)
 		{
 			if(*err)
-				slog.error("%s: %s; %s(%d)", command, err, filename, lnum);
+				slog.error("%s(%d): %s: %s", filename, lnum, command, err);
 			continue;
 		}
 
@@ -1073,7 +1073,7 @@ repname1:
 	if(first && count)
 		initcount = count;
 	else if(count)
-		slog.info("%s: %d steps compiled", script->name, count);
+		slog.info("compiled %s; %d steps", script->name, count);
 	first = false;
 
 	if(!scrStream->eof())
@@ -1097,7 +1097,7 @@ repname1:
 		{
 			if(line->loop != 0xffff)
 			{
-				slog.error("%s: not allowed as initializer; %s(%d)", line->cmd, filename, line->lnum);
+				slog.error("%s(%d): %s: not allowed as initializer",filename, line->lnum, line->cmd); 
 				if(last)
 					last->next = line->next;
 				else
@@ -1106,9 +1106,9 @@ repname1:
 			line = line->next;
 		}	
 		if(initkey == SCRIPT_INDEX_SIZE && initcount)
-			slog.info("%s: %d steps initial", init->name, initcount);
+			slog.info("compiled %s; %d steps", init->name, initcount);
 		else if(initcount)
-			slog.info("%s: %d steps compiled", init->name, initcount);
+			slog.info("compiled %s; %d steps", init->name, initcount);
 		init->next = index[initkey];
 		index[initkey] = init;
 	}
