@@ -440,7 +440,11 @@ void ScriptInterp::trap(unsigned id)
 	frame[stack].tranflag = frame[stack].caseflag = false;
 	frame[stack].line = frame[stack].first = trap;
 	if(!id)
+	{
+		if(!trap)
+			redirect("::exit");
 		exiting = true;
+	}
 }
 
 bool ScriptInterp::pull(void)      
@@ -744,7 +748,8 @@ void ScriptInterp::attach(ScriptCommand *cmdref, ScriptImage *img, Name *scr)
 
 	enterMutex();
 	initRuntime(scr);
-	image->fastBranch(this);
+	if(cmd->ripple)
+		image->fastBranch(this);
 	leaveMutex();
 }
 
@@ -1233,7 +1238,13 @@ const char *ScriptInterp::getOption(const char *def)
 
 const char *ScriptInterp::getSymbol(const char *id)
 {
-	Symbol *sym = mapSymbol(id);
+	const char *val = getExternal(id);
+	Symbol *sym;
+
+	if(val)
+		return val;
+
+	sym = mapSymbol(id);
 
 	if(!sym)
 		return NULL;
