@@ -74,9 +74,9 @@ char Script::decimal = '.';
 const char *Script::plugins = NULL;
 const char *Script::altplugins = NULL;
 
-const char *Script::user = NULL;
-const char *Script::pass = NULL;
-const char *Script::server = "localhost";
+const char *Script::access_user = NULL;
+const char *Script::access_pass = NULL;
+const char *Script::access_host = "localhost";
 
 Script::Test *Script::test = NULL;
 Script::Fun *Script::ifun = NULL;
