@@ -249,9 +249,9 @@ public:
 	static char decimal;
 	static const char *plugins;
 	static const char *altplugins;
-	static const char *user;
-	static const char *pass;
-	static const char *server;
+	static const char *access_user;
+	static const char *access_pass;
+	static const char *access_host;
 
         static void addFunction(const char *name, unsigned count, Function i);
         static void addConditional(const char *name, Cond test);
@@ -355,6 +355,14 @@ public:
 	 */
 	bool control(char **args);
 
+	/**
+	 * Get the active script.
+	 *
+	 * @return pointer to active script image.
+	 */
+	inline ScriptImage *getActive(void)
+		{return active;};
+
 protected:
 	/**
 	 * Fetch whether the given keyword is valid for constructor.
@@ -887,7 +895,6 @@ public:
 	inline unsigned long getInstance(void)
 		{return instance;};
 
-public:
 	/**
 	 * Construct a new working image.  This must be derived to an
 	 * application specific compiler that can scan directories and
@@ -963,6 +970,26 @@ public:
 	 * @return count of entries found.
 	 */
 	unsigned gather(const char *suffix, Name **array, unsigned size);
+
+	/**
+	 * inc the reference count.
+	 */
+	inline void incRef(void)
+		{++refcount;};
+
+	/**
+	 * dec the reference count.
+	 */
+	inline void decRef(void)
+		{--refcount;};
+
+	/**
+	 * See if the image is referenced...
+	 *
+	 * @return true if is referenced.
+	 */
+	inline bool isRef(void)
+		{return (bool)(refcount > 0);};
 };
 
 /**
@@ -1122,6 +1149,9 @@ public:
 	inline unsigned long getSequence(void)
 		{return sequence;};
 
+	virtual const char *getLogname(void)
+		{return logname;};
+
 	virtual ScriptInterp *getInterp(const char *id);
 
 	virtual const char *getExternal(const char *opt);
@@ -1422,8 +1452,6 @@ protected:
 	
 	void exit(const char *errmsg = NULL);
 
-	virtual timeout_t getTimeout(void);
-
 	inline bool isExiting(void)
 		{return exiting;};
 
@@ -1445,6 +1473,8 @@ protected:
 	void release(void);
 
 public:
+	virtual timeout_t getTimeout(void);
+	
 	inline size_t getStack(void)
 		{return stacksize;};
 
